@@ -1,5 +1,5 @@
 package Beam::Runner::Command::list;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 # ABSTRACT: List the available containers and services
 
 #pod =head1 SYNOPSIS
@@ -56,7 +56,13 @@ sub run {
     if ( !$container ) {
         return $class->_list_containers;
     }
-    return $class->_list_services( $container );
+
+    if ( !$class->_list_services( $container ) ) {
+        warn qq{No runnable services in container "$container"\n};
+        return 1;
+    }
+
+    return 0;
 }
 
 #=sub _list_containers
@@ -86,9 +92,13 @@ sub _list_containers {
     }
 
     my @container_names = sort keys %containers;
+    my $printed = 0;
     for my $i ( 0..$#container_names ) {
-        $class->_list_services( $containers{ $container_names[ $i ] } );
-        print "\n" unless $i == $#container_names;
+        if ( $printed ) {
+            print "\n";
+            $printed = 0;
+        }
+        $printed += $class->_list_services( $containers{ $container_names[ $i ] } );
     }
 
     return 0;
@@ -110,9 +120,6 @@ sub _list_services {
         file => $path,
     );
 
-    my ( $bold, $reset ) = ( color( 'bold' ), color( 'reset' ) );
-    print "$bold$cname$reset" . ( eval { " -- " . $wire->get( '$summary' ) } || '' ) . "\n";
-
     my $config = $wire->config;
     my %services;
     for my $name ( keys %$config ) {
@@ -120,9 +127,14 @@ sub _list_services {
         next unless $name;
         $services{ $name } = $abstract;
     }
+    return 0 unless keys %services;
+
+    my ( $bold, $reset ) = ( color( 'bold' ), color( 'reset' ) );
+    print "$bold$cname$reset" . ( eval { " -- " . $wire->get( '$summary' ) } || '' ) . "\n";
+
     my $size = max map { length } keys %services;
     print join( "\n", map { sprintf "- $bold%-${size}s$reset -- %s", $_, $services{ $_ } } sort keys %services ), "\n";
-    return 0;
+    return 1;
 }
 
 #=sub _list_service
@@ -209,7 +221,7 @@ Beam::Runner::Command::list - List the available containers and services
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
